@@ -1,37 +1,36 @@
 package Log::ger::Output::File;
 
-our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-06-23'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use warnings;
 
-use Log::ger::Util;
-
-sub import {
-    my ($package, %import_args) = @_;
+sub get_hooks {
+    my %conf = @_;
 
     my $fh;
-    if (defined(my $path = $import_args{path})) {
+    if (defined(my $path = $conf{path})) {
         open $fh, ">>", $path or die "Can't open log file '$path': $!";
-    } elsif ($fh = $import_args{handle}) {
+    } elsif ($fh = $conf{handle}) {
     } else {
         die "Please specify 'path' or 'handle'";
     }
 
-    my $plugin = sub {
-        my %args = @_;
+    return {
+        create_log_routine => [
+            __PACKAGE__, 50,
+            sub {
+                my %args = @_;
 
-        my $code = sub {
-            print $fh $_[1];
-            print $fh "\n" unless $_[1] =~ /\R\z/;
-            $fh->flush;
-        };
-        [$code];
+                my $logger = sub {
+                    print $fh $_[1];
+                    print $fh "\n" unless $_[1] =~ /\R\z/;
+                    $fh->flush;
+                };
+                [$logger];
+            }],
     };
-
-    Log::ger::Util::add_plugin(
-        'create_log_routine', [50, $plugin, __PACKAGE__], 'replace');
 }
 
 1;
@@ -49,7 +48,7 @@ Log::ger::Output::File - Send logs to file
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -62,7 +61,7 @@ version 0.001
 
 =head1 DESCRIPTION
 
-This is a simple output to file. File will be opened with append more. No
+This is a simple output to file. File will be opened with append mode. No
 locking, rotation, or other fancy features (yet). Filehandle will be flushed
 after each log.
 
